==> cscec5b-ecxj-impl-3.0.0-20230403.024840-5-sources.jar: com/ejianc/business/ecxj/vo/TypeSettingVO.java <==
package com.ejianc.business.ecxj.vo;

import java.util.List;
import java.util.ArrayList;

import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 集采类型设置
 * 
 * @author generator
 * 
 */
public class TypeSettingVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long orgId; // 组织ID
    private Long materialTypeId; // 集采材料类型Id
    private String materialTypeName; // 集采材料类型
    private Integer tenderLevel; // 招标层级
    private String tenderCode; // 招标编码
    private String tenderName; // 招标名称
    private Integer quoteType; // 报价方式
    private Integer settingStatus; // 集采类型状态
    private Integer isUsed; // 是否被引用 0-未引用 1-引用
    private String memo; // 备注

    private List<SettingProductInfoVO> settingProductInfoEntities = new ArrayList<>(); // 设置物资清单实体


    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public Integer getTenderLevel() {
        return tenderLevel;
    }

    public void setTenderLevel(Integer tenderLevel) {
        this.tenderLevel = tenderLevel;
    }
    public String getTenderCode() {
        return tenderCode;
    }

    public void setTenderCode(String tenderCode) {
        this.tenderCode = tenderCode;
    }
    public String getTenderName() {
        return tenderName;
    }

    public void setTenderName(String tenderName) {
        this.tenderName = tenderName;
    }
    public Integer getQuoteType() {
        return quoteType;
    }

    public void setQuoteType(Integer quoteType) {
        this.quoteType = quoteType;
    }
    public Integer getSettingStatus() {
        return settingStatus;
    }

    public void setSettingStatus(Integer settingStatus) {
        this.settingStatus = settingStatus;
    }

    public Integer getIsUsed() {
        return isUsed;
    }

    public void setIsUsed(Integer isUsed) {
        this.isUsed = isUsed;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public List<SettingProductInfoVO> getSettingProductInfoEntities() {
        return settingProductInfoEntities;
    }

    public void setSettingProductInfoEntities(List<SettingProductInfoVO> settingProductInfoEntities) {
        this.settingProductInfoEntities = settingProductInfoEntities;
    }
}

==> cscec5b-ecxj-impl-3.0.0-20230509.073540-32-sources.jar: com/ejianc/business/ecxj/vo/TypeSettingVO.java <==
package com.ejianc.business.ecxj.vo;

import java.util.List;
import java.util.ArrayList;

import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 集采类型设置
 * 
 * @author generator
 * 
 */
public class TypeSettingVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long orgId; // 组织ID
    private Long materialTypeId; // 集采材料类型Id
    private String materialTypeName; // 集采材料类型
    private Integer tenderLevel; // 招标层级
    private String tenderNo; // 招标编码
    private String tenderName; // 招标名称
    private Integer quoteType; // 报价方式
    private Integer settingStatus; // 集采类型状态
    private Integer isUsed; // 是否被引用 0-未引用 1-引用
    private String memo; // 备注

    private List<SettingSupplierInfoVO> settingSupplierInfoEntities = new ArrayList<>(); // 设置物资清单实体
    private List<SettingSupplierInfoVO> noticeSupplierEntities = new ArrayList<>(); // 设置物资清单实体


    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public Integer getTenderLevel() {
        return tenderLevel;
    }

    public void setTenderLevel(Integer tenderLevel) {
        this.tenderLevel = tenderLevel;
    }
    public String getTenderNo() {
        return tenderNo;
    }

    public void setTenderNo(String tenderNo) {
        this.tenderNo = tenderNo;
    }
    public String getTenderName() {
        return tenderName;
    }

    public void setTenderName(String tenderName) {
        this.tenderName = tenderName;
    }
    public Integer getQuoteType() {
        return quoteType;
    }

    public void setQuoteType(Integer quoteType) {
        this.quoteType = quoteType;
    }
    public Integer getSettingStatus() {
        return settingStatus;
    }

    public void setSettingStatus(Integer settingStatus) {
        this.settingStatus = settingStatus;
    }

    public Integer getIsUsed() {
        return isUsed;
    }

    public void setIsUsed(Integer isUsed) {
        this.isUsed = isUsed;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public List<SettingSupplierInfoVO> getSettingSupplierInfoEntities() {
        return settingSupplierInfoEntities;
    }
    public void setSettingSupplierInfoEntities(List<SettingSupplierInfoVO> settingSupplierInfoEntities) {
        this.settingSupplierInfoEntities = settingSupplierInfoEntities;
    }

    public List<SettingSupplierInfoVO> getNoticeSupplierEntities() {
        return noticeSupplierEntities;
    }
    public void setNoticeSupplierEntities(List<SettingSupplierInfoVO> noticeSupplierEntities) {
        this.noticeSupplierEntities = noticeSupplierEntities;
    }
}
